@@ -38,13 +38,12 @@ import com.sencha.gxt.data.shared.loader.ListLoadResultBean;
 import com.sencha.gxt.data.shared.loader.ListLoader;
 import com.sencha.gxt.data.shared.loader.LoadResultListStoreBinding;
 import com.sencha.gxt.widget.core.client.ContentPanel;
-import com.sencha.gxt.widget.core.client.Dialog.PredefinedButton;
 import com.sencha.gxt.widget.core.client.box.ConfirmMessageBox;
 import com.sencha.gxt.widget.core.client.button.TextButton;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
-import com.sencha.gxt.widget.core.client.event.HideEvent;
-import com.sencha.gxt.widget.core.client.event.HideEvent.HideHandler;
+import com.sencha.gxt.widget.core.client.event.DialogHideEvent;
+import com.sencha.gxt.widget.core.client.event.DialogHideEvent.DialogHideHandler;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
 import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
 import com.sencha.gxt.widget.core.client.form.TextField;
@@ -75,7 +74,7 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 	protected static final ColumnConfig<TabResource, String> ownerColumn = new ColumnConfig<TabResource, String>(
 			properties.ownerLogin(), 70, "Owner");
 	protected static final ColumnConfig<TabResource, String> dateColumn = new ColumnConfig<TabResource, String>(
-			properties.date(), 50, "Date");
+			properties.date(), 50, "Creation Date");
 
 	protected Grid<TabResource> grid;
 	protected ResourceBundle res;
@@ -320,8 +319,32 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 		removableTR = tabResource;
 		final ConfirmMessageBox mb = new ConfirmMessageBox("Delete",
 				"Would you like to delete this tabular resource?");
+		
+		/*Next in GXT 3.1.1 */
+		 
+		mb.addDialogHideHandler(new DialogHideHandler() {
+
+			@Override
+			public void onDialogHide(DialogHideEvent event) {
+				switch (event.getHideButton()) {
+				case NO:
+					break;
+				case YES:
+					callDeleteTabularResource();
+					break;
+				default:
+					break;
+
+				}
+
+			}
+		});
+		
+		/* GXT 3.0.1
 		mb.addHideHandler(new HideHandler() {
 			public void onHide(HideEvent event) {
+				
+				
 				if (mb.getHideButton() == mb.getButtonById(PredefinedButton.YES
 						.name())) {
 					callDeleteTabularResource();
@@ -329,8 +352,10 @@ public class TabResourcesSelectionPanel extends ContentPanel implements
 						.getButtonById(PredefinedButton.NO.name())) {
 					// perform NO action
 				}
+				
 			}
 		});
+		*/
 		mb.setWidth(300);
 		mb.show();
 
