@@ -24,6 +24,7 @@ import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.widget.core.client.FramedPanel;
 import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutData;
 import com.sencha.gxt.widget.core.client.container.HtmlLayoutContainer;
+import com.sencha.gxt.widget.core.client.container.MarginData;
 import com.sencha.gxt.widget.core.client.container.VBoxLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VBoxLayoutContainer.VBoxLayoutAlign;
 
@@ -81,7 +82,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 		operationInProgressPanel.add(resultField, new BoxLayoutData(
 				new Margins(10, 5, 10, 5)));
 
-		setContent(operationInProgressPanel);
+		setCenterWidget(operationInProgressPanel, new MarginData(0));
 		resultField.setVisible(false);
 
 	}
@@ -108,18 +109,18 @@ public class UnionOperationInProgressCard extends WizardCard implements
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
 								showErrorAndHide("Error Locked",
-										caught.getLocalizedMessage(), caught);
+										caught.getLocalizedMessage(), "",
+										caught);
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
 									showErrorAndHide("Error Final",
-											caught.getLocalizedMessage(),
+											caught.getLocalizedMessage(), "",
 											caught);
 								} else {
-									showErrorAndHide(
-											"Error in Union",
-											"An error occured in union: "
-													+ caught.getLocalizedMessage(),
+									showErrorAndHide("Error in Union",
+											"An error occured in union.",
+											caught.getLocalizedMessage(),
 											caught);
 								}
 							}
@@ -133,7 +134,6 @@ public class UnionOperationInProgressCard extends WizardCard implements
 	public void setup() {
 		getWizardWindow().setEnableBackButton(false);
 		setBackButtonVisible(false);
-		setNextButtonVisible(false);
 		getWizardWindow().setEnableNextButton(false);
 		getWizardWindow().setNextButtonToFinish();
 		startUnion();
@@ -189,7 +189,7 @@ public class UnionOperationInProgressCard extends WizardCard implements
 							new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 		} else {
-			showErrorAndHide("Error in Union", reason, caught);
+			showErrorAndHide("Error in Union", reason, details, caught);
 
 		}
 		forceLayout();
